@@ -36,44 +36,55 @@ atom_properties = {
     "angmom": {"type": 3, "gtype": 1, "dim": 3},
     "torque": {"type": 3, "gtype": 1, "dim": 3},
     "radius": {"type": 2, "gtype": 1, "dim": 1},
+    "image": {"type": 2, "gtype": 0, "dim": 3},
     # we can add more quantities as needed
     # taken directly from atom.cpp -> extract()
 }
 
 # Lammps executable
-job = lammps(cmdargs=["-screen", "none"])
+args = ["-screen", "none"]
+if len(sys.argv) > 1:
+    args.extend(sys.argv[1:])
+job = lammps(cmdargs=args)
 
 
 def extract_compute(funct_args):
-    # if MPI.COMM_WORLD.rank == 0:
+    def convert_data(val, type, length, width):
+        data = []
+        if type == 2:
+            for i in range(length):
+                dummy = []
+                for j in range(width):
+                    dummy.append(val[i][j])
+                data.append(np.array(dummy))
+            data = np.array(data)
+        elif type == 1:
+            for i in range(length):
+                data.append(val[i])
+            data = np.array(data)
+        else:
+            data = val
+        return data
+
     id = funct_args[0]
-    style =  funct_args[1]
+    style = funct_args[1]
     type = funct_args[2]
     length = funct_args[3]
     width = funct_args[4]
+
     filtered_args = [id, style, type]
-
-    val = job.extract_compute(*filtered_args)
-
-    # now process
-    # length should be set
-    data = []
-    if style == 1:
-        length = job.get_natoms()
-    if type == 2:
-        for i in range(length):
-            dummy = []
-            for j in range(width):
-                dummy.append(val[i][j])
-            data.append(np.array(dummy))
-        data = np.array(data)
-    elif type == 1:
-        for i in range(length):
-            data.append(val[i])
-        data = np.array(data)
-    else:
-        data = val
-    return data
+    if style == 0:
+        val = job.extract_compute(*filtered_args)
+        return convert_data(val=val, type=type, length=length, width=width)
+    elif style == 1:  # per atom property
+        val = _gather_data_from_all_processors(
+            data=job.numpy.extract_compute(*filtered_args)
+        )
+        if MPI.COMM_WORLD.rank == 0:
+            length = job.get_natoms()
+            return convert_data(val=val, type=type, length=length, width=width)
+    else:  # Todo
+        raise ValueError("Local style is currently not supported")
 
 
 def get_version(funct_args):
@@ -149,15 +160,20 @@ def extract_fix(funct_args):
 def extract_variable(funct_args):
     # in the args - if the third one,
     # which is the type is 1 - a lammps array is returned
-    if MPI.COMM_WORLD.rank == 0:
-        # if type is 1 - reformat file
-        try:
-            data = job.extract_variable(*funct_args)
-        except ValueError:
-            return []
-        if funct_args[2] == 1:
-            data = np.array(data)
-        return data
+    if funct_args[2] == 1:
+        data = _gather_data_from_all_processors(
+            data=job.numpy.extract_variable(*funct_args)
+        )
+        if MPI.COMM_WORLD.rank == 0:
+            return np.array(data)
+    else:
+        if MPI.COMM_WORLD.rank == 0:
+            # if type is 1 - reformat file
+            try:
+                data = job.extract_variable(*funct_args)
+            except ValueError:
+                return []
+            return data
 
 
 def get_natoms(funct_args):
@@ -184,7 +200,9 @@ def gather_atoms(funct_args):
     # this block prevents error when trying to access values
     # that do not exist
     try:
-        val = job.gather_atoms(name, atom_properties[name]["gtype"], atom_properties[name]["dim"])
+        val = job.gather_atoms(
+            name, atom_properties[name]["gtype"], atom_properties[name]["dim"]
+        )
     except ValueError:
         return []
     # this is per atom quantity - so get
@@ -192,7 +210,7 @@ def gather_atoms(funct_args):
     val = list(val)
     dim = atom_properties[name]["dim"]
     if dim > 1:
-        data = [val[x:x+dim] for x in range(0, len(val), dim)]
+        data = [val[x : x + dim] for x in range(0, len(val), dim)]
     else:
         data = list(val)
     return np.array(data)
@@ -208,7 +226,9 @@ def gather_atoms_concat(funct_args):
     # this block prevents error when trying to access values
     # that do not exist
     try:
-        val = job.gather_atoms_concat(name, atom_properties[name]["gtype"], atom_properties[name]["dim"])
+        val = job.gather_atoms_concat(
+            name, atom_properties[name]["gtype"], atom_properties[name]["dim"]
+        )
     except ValueError:
         return []
     # this is per atom quantity - so get
@@ -216,7 +236,7 @@ def gather_atoms_concat(funct_args):
     val = list(val)
     dim = atom_properties[name]["dim"]
     if dim > 1:
-        data = [val[x:x+dim] for x in range(0, len(val), dim)]
+        data = [val[x : x + dim] for x in range(0, len(val), dim)]
     else:
         data = list(val)
     return np.array(data)
@@ -229,7 +249,7 @@ def gather_atoms_subset(funct_args):
     ids = funct_args[2]
 
     # prep ids
-    cids = (lenids*c_int)()
+    cids = (lenids * c_int)()
     for i in range(lenids):
         cids[i] = ids[i]
 
@@ -239,15 +259,21 @@ def gather_atoms_subset(funct_args):
     # this block prevents error when trying to access values
     # that do not exist
     try:
-        val = job.gather_atoms_subset(name, atom_properties[name]["gtype"], atom_properties[name]["dim"], lenids, cids)
+        val = job.gather_atoms_subset(
+            name,
+            atom_properties[name]["gtype"],
+            atom_properties[name]["dim"],
+            lenids,
+            cids,
+        )
     except ValueError:
         return []
     # this is per atom quantity - so get
     # number of atoms - first dimension
     val = list(val)
     dim = atom_properties[name]["dim"]
-    if dim>1:
-        data = [val[x:x+dim] for x in range(0, len(val), dim)]
+    if dim > 1:
+        data = [val[x : x + dim] for x in range(0, len(val), dim)]
     else:
         data = list(val)
     return np.array(data)
@@ -352,7 +378,9 @@ def scatter_atoms(funct_args):
     else:
         c_vector = (len(py_vector) * c_double)(*py_vector)
 
-    job.scatter_atoms(name, atom_properties[name]["gtype"], atom_properties[name]["dim"], c_vector)
+    job.scatter_atoms(
+        name, atom_properties[name]["gtype"], atom_properties[name]["dim"], c_vector
+    )
     return 1
 
 
@@ -362,7 +390,7 @@ def scatter_atoms_subset(funct_args):
     ids = funct_args[3]
 
     # prep ids
-    cids = (lenids*c_int)()
+    cids = (lenids * c_int)()
     for i in range(lenids):
         cids[i] = ids[i]
 
@@ -375,7 +403,14 @@ def scatter_atoms_subset(funct_args):
     else:
         c_vector = (len(py_vector) * c_double)(*py_vector)
 
-    job.scatter_atoms_subset(name, atom_properties[name]["gtype"], atom_properties[name]["dim"], lenids, cids, c_vector)
+    job.scatter_atoms_subset(
+        name,
+        atom_properties[name]["gtype"],
+        atom_properties[name]["dim"],
+        lenids,
+        cids,
+        c_vector,
+    )
     return 1
 
 
@@ -397,18 +432,56 @@ def select_cmd(argument):
     switcher = {
         f.__name__: f
         for f in [
-            extract_compute, get_version, get_file, commands_list, commands_string,
-            extract_setting, extract_global, extract_box, extract_atom, extract_fix, extract_variable,
-            get_natoms, set_variable, reset_box, gather_atoms_concat, gather_atoms_subset,
-            scatter_atoms_subset, create_atoms, has_exceptions, has_gzip_support, has_png_support,
-            has_jpeg_support, has_ffmpeg_support, installed_packages, set_fix_external_callback,
-            get_neighlist, find_pair_neighlist, find_fix_neighlist, find_compute_neighlist, get_neighlist_size,
-            get_neighlist_element_neighbors, get_thermo, scatter_atoms, command, gather_atoms
+            extract_compute,
+            get_version,
+            get_file,
+            commands_list,
+            commands_string,
+            extract_setting,
+            extract_global,
+            extract_box,
+            extract_atom,
+            extract_fix,
+            extract_variable,
+            get_natoms,
+            set_variable,
+            reset_box,
+            gather_atoms_concat,
+            gather_atoms_subset,
+            scatter_atoms_subset,
+            create_atoms,
+            has_exceptions,
+            has_gzip_support,
+            has_png_support,
+            has_jpeg_support,
+            has_ffmpeg_support,
+            installed_packages,
+            set_fix_external_callback,
+            get_neighlist,
+            find_pair_neighlist,
+            find_fix_neighlist,
+            find_compute_neighlist,
+            get_neighlist_size,
+            get_neighlist_element_neighbors,
+            get_thermo,
+            scatter_atoms,
+            command,
+            gather_atoms,
         ]
     }
     return switcher.get(argument)
 
 
+def _gather_data_from_all_processors(data):
+    data_gather = MPI.COMM_WORLD.gather(data, root=0)
+    if MPI.COMM_WORLD.rank == 0:
+        data = []
+        for vl in data_gather:
+            for v in vl:
+                data.append(v)
+        return data
+
+
 if __name__ == "__main__":
     while True:
         if MPI.COMM_WORLD.rank == 0:
