@@ -20,17 +20,28 @@ __date__ = "Feb 28, 2020"
 
 
 class LammpsBase:
-    def __init__(self, cores=8, working_directory="."):
+    def __init__(self, cores=8, working_directory=".", cmdargs=None):
         self.cores = cores
         self.working_directory = working_directory
         self._process = None
+        self._cmdargs = cmdargs
 
     def start_process(self):
         executable = os.path.join(
             os.path.dirname(os.path.abspath(__file__)), "../mpi", "lmpmpi.py"
         )
+        cmds = [
+            "mpiexec",
+            "--oversubscribe",
+            "-n",
+            str(self.cores),
+            "python",
+            executable,
+        ]
+        if self._cmdargs is not None:
+            cmds.extend(self._cmdargs)
         self._process = subprocess.Popen(
-            ["mpiexec", "--oversubscribe", "-n", str(self.cores), "python", executable],
+            cmds,
             stdout=subprocess.PIPE,
             stderr=None,
             stdin=subprocess.PIPE,
@@ -107,7 +118,7 @@ class LammpsBase:
         self._send(command="get_file", data=[inputfile])
         _ = self._receive()
 
-    #TODO
+    # TODO
     def extract_setting(self, *args):
         self._send(command="extract_setting", data=list(args))
         return self._receive()
@@ -310,7 +321,45 @@ class LammpsBase:
         self._send(command="reset_box", data=list(args))
         _ = self._receive()
 
-    def generate_atoms(self, ids=None, type=None, x=None, v=None, image=None, shrinkexceed=False):
+    def generate_atoms(
+        self, ids=None, type=None, x=None, v=None, image=None, shrinkexceed=False
+    ):
+        """
+        Create atoms on all procs
+
+        Parameters
+        ----------
+        ids : list of ints, optional
+            ids of N atoms that need to be created
+            if not specified, ids from 1 to N are assigned
+
+        type : list of atom types, optional
+            type of N atoms, if not specied, all atoms are assigned as type 1
+
+        x: list of positions
+            list of the type `[posx, posy, posz]` for N atoms
+
+        v: list of velocities
+            list of the type `[vx, vy, vz]` for N atoms
+
+        image: list of ints, optional
+            if not specified a list of 0s will be used.
+
+        shrinkexceed: bool, optional
+            default False
+
+        Returns
+        -------
+        None
+
+        """
+        self.create_atoms(
+            ids=ids, type=type, x=x, v=v, image=image, shrinkexceed=shrinkexceed
+        )
+
+    def create_atoms(
+        self, ids=None, type=None, x=None, v=None, image=None, shrinkexceed=False
+    ):
         """
         Create atoms on all procs
 
@@ -344,11 +393,11 @@ class LammpsBase:
         if x is not None:
             natoms = len(x)
             if type is None:
-                type = [1]*natoms
+                type = [1] * natoms
             if ids is None:
-                ids = list(range(1, natoms+1))
+                ids = list(range(1, natoms + 1))
             if image is None:
-                image = [0]*natoms
+                image = [0] * natoms
 
             funct_args = [natoms, ids, type, x, v, image, shrinkexceed]
             self._send(command="create_atoms", data=funct_args)
@@ -358,7 +407,7 @@ class LammpsBase:
 
     @property
     def has_exceptions(self):
-        """ Return whether the LAMMPS shared library was compiled with C++ exceptions handling enabled """
+        """Return whether the LAMMPS shared library was compiled with C++ exceptions handling enabled"""
         self._send(command="has_exceptions", data=[])
         return self._receive()
 
@@ -419,7 +468,7 @@ class LammpsBase:
         :type  request:   int, optional
         :return: neighbor list index if found, otherwise -1
         :rtype:  int
-         """
+        """
         self._send(command="find_pair_neighlist", data=list(args))
         return self._receive()
 
@@ -431,7 +480,7 @@ class LammpsBase:
         :type  request:   int, optional
         :return: neighbor list index if found, otherwise -1
         :rtype:  int
-         """
+        """
         self._send(command="find_fix_neighlist", data=list(args))
         return self._receive()
 
@@ -443,7 +492,7 @@ class LammpsBase:
         :type  request:   int, optional
         :return: neighbor list index if found, otherwise -1
         :rtype:  int
-         """
+        """
         self._send(command="find_compute_neighlist", data=list(args))
         return self._receive()
 
@@ -453,7 +502,7 @@ class LammpsBase:
         :type  idx: int
         :return: number of elements in neighbor list with index idx
         :rtype:  int
-         """
+        """
         self._send(command="get_neighlist_size", data=list(args))
         return self._receive()
 
@@ -478,8 +527,8 @@ class LammpsBase:
             for c in cmd:
                 self._send(command="command", data=c)
                 _ = self._receive()
-        elif len(cmd.split('\n')) > 1:
-            for c in cmd.split('\n'):
+        elif len(cmd.split("\n")) > 1:
+            for c in cmd.split("\n"):
                 self._send(command="command", data=c)
                 _ = self._receive()
         else:
@@ -566,7 +615,7 @@ class LammpsBase:
         self._send(command="get_thermo", data=list(args))
         return self._receive()
 
-    #TODO
+    # TODO
     def extract_compute(self, id, style, type, length=0, width=0):
         """
         Extract compute value from the lammps library
@@ -622,7 +671,7 @@ class LammpsBase:
             pass
         self._process = None
 
-    #TODO
+    # TODO
     def __del__(self):
         if self._process is not None:
             self.close()
